import SwiftUI

struct ContentView: View {
    @State private var totalAmount: String = ""
    @State private var tipPercentage: Double = 10.0
    @State private var splitCount: Double = 2.0
    
    // Computed properties to calculate the tip and total amounts
    var totalBill: Double {
        return Double(totalAmount) ?? 0.0
    }
    
    var totalTip: Double {
        return totalBill * (tipPercentage / 100)
    }
    
    var totalWithTip: Double {
        return totalBill + totalTip
    }
    
    var amountPerPerson: Double {
        return totalWithTip / splitCount
    }
    
    var body: some View {
        VStack(spacing: 20) {
            
            HStack {
                VStack(alignment: .leading) {
                    Text("Total Bill")
                        .font(.caption)
                        .foregroundColor(.gray)
                    Text("$\(totalBill, specifier: "%.2f")")
                        .font(.headline)
                }
                
                Spacer()
                
                VStack(alignment: .leading) {
                    Text("Total Tip")
                        .font(.caption)
                        .foregroundColor(.gray)
                    Text("$\(totalTip, specifier: "%.2f")")
                        .font(.headline)
                }
            }
            .padding()
            .background(Color(.systemGray6))
            .cornerRadius(10)
            .padding(.horizontal)
            
            // Bill input
            VStack(alignment: .leading, spacing: 10) {
                Text("Enter bill total")
                    .font(.headline)
                
                HStack {
                    Text("$")
                    TextField("Amount", text: $totalAmount)
                        .keyboardType(.decimalPad)
                        .padding()
                        .background(RoundedRectangle(cornerRadius: 8).stroke(Color.green, lineWidth: 2))
                }
                .padding(.horizontal)
            }
            .padding(.horizontal)
            
            // Tip section
            VStack {
                Text("Tip")
                    .font(.headline)
                
                HStack {
                    Slider(value: $tipPercentage, in: 0...100, step: 1)
                    Text("\(Int(tipPercentage))%")
                        .font(.headline)
                }
                .padding(.horizontal)
            }
            
           
            // Round up/down buttons
            HStack {
                Button(action: {
                    roundUp()
                }) {
                    Text("Round Up")
                        .font(.headline)
                        .frame(width: 150, height: 50)
                        .background(Color("DarkGreen"))
                        .foregroundColor(.white)
                        .cornerRadius(25)
                }
                
                Spacer()
                
                Button(action: {
                    roundDown()
                }) {
                    Text("Round Down")
                        .font(.headline)
                        .frame(width: 150, height: 50)
                        .background(Color("DarkGreen"))
                        .foregroundColor(.white)
                        .cornerRadius(25)
                }
            }
            .padding(.horizontal)
        }
        .padding()
    }
    
    // Round up the total per person
    func roundUp() {
        let roundedUpValue = ceil(amountPerPerson)
        let difference = roundedUpValue - amountPerPerson
        totalAmount = String(format: "%.2f", totalBill + difference * splitCount)
    }
    
    // Round down the total per person
    func roundDown() {
        let roundedDownValue = floor(amountPerPerson)
        let difference = amountPerPerson - roundedDownValue
        totalAmount = String(format: "%.2f", totalBill - difference * splitCount)
    }
}

#Preview {
    ContentView()
}
